@@ -1,9 +1,9 @@
-use pipebuilder_common::BaseConfig;
+use pipebuilder_common::{grpc::client::RpcClientConfig, BaseConfig};
 use serde::Deserialize;
 
 #[derive(Deserialize)]
 pub struct BuilderConfig {
-    pub repository_endpoint: String,
+    pub repository_client: RpcClientConfig,
     pub workspace: String,
     pub restore_directory: String,
     pub log_directory: String,
